Διενέργεια εκτίμησης κινδύνων με το OiRA | OiRA

Θέματα

# Διενέργεια εκτίμησης κινδύνων με το OiRA

## Έναρξη νέας συνεδρίας

Για να ξεκινήσετε μια νέα εκτίμηση κινδύνου, κάντε «κλικ» στον σύνδεσμο «Έναρξη νέας συνεδρίας».

## Έναρξη εκτίμησης κινδύνου

Αφού ξεκινήσετε την εκτίμηση κινδύνων, μπορείτε ανά πάσα στιγμή να την ανακτήσετε μέσω του πίνακα εργαλείων υπό τον τίτλο «Οι εκτιμήσεις κινδύνου που έχω διενεργήσει». Από εδώ μπορείτε επίσης να ξεκινήσετε μια νέα εκτίμηση κινδύνου.

Πίνακας εργαλείων.

## Πλοήγηση στην εκτίμηση κινδύνου

Κάθε εκτίμηση κινδύνου σας καθοδηγεί μέσω διάφορων σταδίων. Τα στάδια αυτά είναι ορατά στο κύριο μενού στην αριστερή πλευρά της οθόνης:

- Προετοιμασία
- Συμμετοχή
- Αναγνώριση + Αξιολόγηση
- Σχέδιο δράσης:
- Έκθεση
- Κατάσταση

Ανάλογα με τις αποφάσεις που έχουν λάβει οι εταίροι/οι υπεύθυνοι ανάπτυξης του OiRA, η δομή κάθε εργαλείου μπορεί να ποικίλλει. Σε ορισμένα εργαλεία το στάδιο της αναγνώρισης και της αξιολόγησης περιλαμβάνει το σχέδιο δράσης. Στην περίπτωση αυτή το μενού στην αριστερή πλευρά της οθόνης εμφανίζεται ως εξής:

- Προετοιμασία
- Συμμετοχή
- Αξιολόγηση
- Έκθεση
- Κατάσταση

## Προετοιμασία

Η «Προετοιμασία» είναι το σημείο αφετηρίας κάθε συνεδρίας/εργαλείου. Είναι το σημείο όπου δίνετε στην εκτίμηση κινδύνου κάποιο όνομα, το οποίο στη συνέχεια θα σας βοηθήσει να διακρίνετε μεταξύ των διάφορων εκτιμήσεων κινδύνου που έχετε διενεργήσει, χρησιμοποιώντας το εργαλείο.

Ο σύνδεσμος «Μάθετε περισσότερα σχετικά με αυτό το εργαλείο…» σας παρέχει περισσότερες πληροφορίες σχετικά με το επιλεγμένο εργαλείο και τα μέρη που συμμετείχαν στην ανάπτυξή του.

Αφού κάνετε «κλικ» στο «Έναρξη», ενδέχεται να τεθούν ορισμένες συμπληρωματικές ερωτήσεις, ανάλογα με το εργαλείο που χρησιμοποιείτε. Η προκαταρκτική αυτή οθόνη με ερωτήσεις σχετικά με το προφίλ της επιχείρησης εμφανίζεται μόνο σε εργαλεία που παρέχουν αυτήν την επιλογή.

Στην περίπτωση αυτή έχετε τη δυνατότητα:

- Να επιλέξετε ή να παραλείψετε κάποια κατάσταση/κάποιες καταστάσεις με βάση το κατά πόσον η εν λόγω κατάσταση/οι εν λόγω καταστάσεις συντρέχουν στο πλαίσιο της επιχειρηματικής σας δραστηριότητας. Επιλέξτε «ναι» κατά περίπτωση.
- Να απαριθμήσετε διάφορες επιχειρηματικές μονάδες, υποκαταστήματα ή καταστήματα κ.ο.κ. Οι συναφείς κίνδυνοι θα επαναλαμβάνονται για κάθε εγγραφή.

Η οθόνη «Προφίλ» στο στάδιο «Προετοιμασία»

Το στάδιο της προετοιμασίας είναι πολύ σημαντικό καθώς καθορίζει επακριβώς τον τύπο της επιχείρησης και τους συναφείς κινδύνους που αντιμετωπίζει η επιχείρησή σας. Αφού κάνετε «κλικ» στο «Αποθήκευση και συνέχεια», θα οδηγηθείτε στην επόμενη ενότητα, η οποία έχει τον τίτλο «Συμμετοχή».

Σημείωση: Πολλά εργαλεία δεν περιέχουν ερωτήσεις σχετικές με το προφίλ της επιχείρησης καθώς δεν χρησιμοποιούν το εν λόγω χαρακτηριστικό για τη στόχευση του εργαλείου. Στην περίπτωση αυτή η εν λόγω οθόνη παραλείπεται αυτομάτως.

## Συμμετοχή

Το βήμα αυτό υπενθυμίζει τη σημασία της συμμετοχής των εργαζομένων και παρουσιάζει διάφορους τρόπους για να εξασφαλιστεί η καλή συμμετοχή των εργαζομένων. Εδώ μπορείτε να μεταφορτώσετε ή εκτυπώσετε τα περιεχόμενα της εκτίμησης των κινδύνων για να τα κοινοποιήσετε στους εργαζομένους/υπαλλήλους σας. Με τον τρόπο αυτό διασφαλίζεται ότι οι εργαζόμενοι είναι σε θέση να συμβάλλουν στην αξιολόγηση της κατάστασης στον χώρο εργασίας τους.

## Αξιολόγηση

Στο στάδιο αυτό θα αναγνωρίσετε κινδύνους και προβλήματα σχετικά με την επιχείρησή σας.

Σημείωση: Ανάλογα με την προσαρμογή του εργαλείου από τον εταίρο OiRA, το στάδιο «Σχέδιο δράσης» (βλ. κατωτέρω) ενδέχεται να έχει ενσωματωθεί στην παρούσα οθόνη. Στην περίπτωση αυτή, ολόκληρο το στάδιο ονομάζεται «Αξιολόγηση» και τα στοιχεία που περιγράφονται στο «Σχέδιο δράσης» θα εμφανίζονται στον προσδιορισμό και την αξιολόγηση κάθε κινδύνου.

Αναγνώριση και αξιολόγηση.

Στην αριστερή πλευρά της οθόνης, κάτω από το «Αναγνώριση + Αξιολόγηση»/«Εκτίμηση», μπορείτε να δείτε όλα τα θέματα/τις θεματικές ενότητες που περιλαμβάνονται στο εργαλείο. Το θέμα που παρακολουθείτε αυτή τη στιγμή είναι επισημασμένο.

### Αναγνώριση

Για κάθε κίνδυνο πρέπει να αποφασίσετε αν η δήλωση που περιγράφει μια επιθυμητή κατάσταση ισχύει στην επιχείρησή σας. Μπορείτε να απαντήσετε ως εξής:

- Ναι: εάν στη δήλωση απαντήσετε «ναι», δεν χρειάζεται καμία επιπλέον ενέργεια, καθώς έχετε εκτιμήσει ότι ο κίνδυνος δεν υφίσταται.
- Όχι: εάν στη δήλωση απαντήσετε «όχι», χρειάζονται επιπλέον ενέργειες. Θα σας ζητηθεί να αποφασίσετε σχετικά με συγκεκριμένα μέτρα.
- Μη αποδεκτή: ορισμένες δηλώσεις κινδύνου παρέχουν τη δυνατότητα να επιλέξετε «μη αποδεκτή» εφόσον ο κίνδυνος δεν είναι συναφής με την εταιρία/επιχείρησή σας.

Κάτω από κάθε δήλωση παρατίθενται συνήθως περισσότερες πληροφορίες για τον συγκεκριμένο κίνδυνο:

- Πληροφορία: σύντομη περιγραφή, ενίοτε συνοδευόμενη από εικόνες, η οποία παρέχει περισσότερες λεπτομέρειες σχετικά με τον κίνδυνο.
- Πηγές: συμπληρωματικές πληροφορίες σχετικά με τον κίνδυνο, όπως παραπομπές σε νομικές πράξεις και κείμενα πολιτικής. Ενίοτε μπορείτε να βρείτε εδώ συνημμένα έγγραφα για περαιτέρω μελέτη.
- Σχόλια: εδώ μπορείτε να εισαγάγετε τα σχόλιά σας, τα οποία θα εμφανιστούν στην έκθεσή σας στο τέλος της αξιολόγησης.

Αφού απαντήσετε σε μια δήλωση κινδύνου και συνεχίσετε, το μενού στην αριστερή πλευρά της οθόνης θα επικαιροποιηθεί με ένα έγχρωμο σύμβολο που θα δείχνει εάν:

- απαντήσατε θετικά (πράσινο «τικ»)
- απαντήσατε αρνητικά (κόκκινος σταυρός)
- αναβάλατε την απάντηση (πορτοκαλί ερωτηματικό)

Στις αναπάντητες ερωτήσεις παραμένει το γκρίζο σύμβολο.

### Αξιολόγηση

Στο στάδιο αυτό αξιολογείτε την προτεραιότητα του κινδύνου που έχετε αναγνωρίσει.

Αξιολόγηση κινδύνου.

Σημείωση: Σε ορισμένα εργαλεία OiRA δεν εμφανίζεται η αξιολόγηση. Αυτό εξαρτάται από τον τρόπο με τον οποίο ο εθνικός εταίρος/υπεύθυνος ανάπτυξης διαμόρφωσε το συγκεκριμένο εργαλείο OiRA.

Εάν έχετε αναγνωρίσει κάποιον κίνδυνο ως παρόντα (οπότε εμφανίζεται ο κόκκινος σταυρός), εμφανίζεται η ενότητα για την αξιολόγηση. Ανάλογα με τη μέθοδο αξιολόγησης που εφαρμόζεται για κάθε κίνδυνο, θα κληθείτε να:

- εκτιμήσετε την προτεραιότητα: υψηλή, μέτρια, χαμηλή

Καθορισμός προτεραιότητας του κινδύνου

Ή

- απαντήσετε μερικές ερωτήσεις σχετικά με τη συχνότητα, τη σοβαρότητα και την πιθανότητα του κινδύνου, ώστε να υπολογιστεί ο βαθμός προτεραιότητας με βάση τις απαντήσεις σας.

Καθορισμός μεταβλητών για κάποιον κίνδυνο.

### Κίνδυνοι κατά προτεραιότητα που έχουν καθοριστεί από τον εκάστοτε τομέα:

Ορισμένοι κίνδυνοι θεωρούνται εξαιρετικά σημαντικοί από τον εθνικό εταίρο/υπεύθυνο ανάπτυξης που δημιούργησε το συγκεκριμένο εργαλείο OiRA. Δεν υποχρεούστε να εκτιμήσετε τέτοιους «κινδύνους κατά προτεραιότητα», καθώς ο βαθμός προτεραιότητάς τους ορίζεται αυτομάτως ως «υψηλός».

Κίνδυνοι κατά προτεραιότητα.

### Εξατομικευμένοι κίνδυνοι

Αφού απαντήσετε σε όλα τα θέματα που αφορούν κινδύνους στο πλαίσιο της «Αναγνώρισης + Αξιολόγησης/«Εκτίμησης», θα φθάσετε στο προαιρετικό θέμα «Άλλοι κίνδυνοι». Εδώ, κάνοντας «κλικ» στο «Προσθέστε έναν εξατομικευμένο κίνδυνο», μπορείτε να δημιουργήσετε τις δικές σας καταχωρίσεις.

Εάν κίνδυνοι που απουσιάζουν από το εργαλείο είναι παρόντες στον χώρο εργασίας σας/στην επιχείρησή σας, μπορείτε να τους προσθέσετε εδώ. Οι κίνδυνοι αυτοί είναι δυνατόν να καθοριστούν/διατυπωθούν πλήρως από εσάς.

Εξατομικευμένοι κίνδυνοι.

Ένας «εξατομικευμένος κίνδυνος» λειτουργεί με πολύ παρόμοιο τρόπο με τους κινδύνους που παρουσιάζονται από το εργαλείο OiRA, αλλά προφανώς πρέπει να τον περιγράψετε γραπτώς. Το κείμενο αυτό πρέπει να είναι τουλάχιστον μια σύντομη δήλωση που περιγράφει μια προβληματική κατάσταση, με δυνατότητα μεγαλύτερης περιγραφής. Μπορείτε επίσης να τηλεφορτώσετε μια εικόνα για μια συγκεκριμένη κατάσταση.

Όπως και για τους συνήθεις κινδύνους, πρέπει να δηλώσετε αν ο κίνδυνος υπάρχει ή όχι. Αυτό θα σας επιτρέψει να διαγράψετε τους εξατομικευμένους κινδύνους μόλις τους αντιμετωπίσετε επιτυχώς, όμως να διατηρήσετε αποθηκευμένη την εκτίμηση κινδύνου που εκπονήσατε για λόγους τεκμηρίωσης.

Μπορείτε να προσθέσετε όσους εξατομικευμένους κινδύνους χρειαστεί.

Προσθήκη εξατομικευμένου κινδύνου.

## Σχέδιο δράσης

Στο στάδιο αυτό αποφασίζετε σχετικά με τα μέτρα που επιθυμείτε να εφαρμόσετε για την εξάλειψη ή τη μείωση των κινδύνων που προηγουμένως έχετε αναγνωρίσει.

Σημείωση: Όπως ήδη προαναφέρθηκε, το σχέδιο δράσης παρουσιάζεται ως χωριστό στάδιο στο μενού στην αριστερή πλευρά της οθόνης ή εμφανίζεται κάτω από κάθε αναγνωρισμένο κίνδυνο. Στη δεύτερη περίπτωση, το στάδιο στο μενού καλείται «Εκτίμηση» και περιλαμβάνει τόσο τις δηλώσεις κινδύνου όσο και μια επιλογή απαντήσεων.

Η έκδοση που έχετε στη διάθεσή σας είναι αποτέλεσμα των αποφάσεων που έλαβε ο εθνικός εταίρος/υπεύθυνος ανάπτυξης του εργαλείου OiRA.

### Ενσωματωμένο σχέδιο δράσης

Ενσωματωμένο σχέδιο δράσης.

Αν απαντήσετε σε κάποια ερώτηση «Όχι», τότε θα εμφανιστεί στη σελίδα η θεματική ενότητα του σχεδίου δράσης, υπό τον τίτλο «Μέτρα».

Μπορείτε ταυτόχρονα να επιλέξετε από έναν κατάλογο μέτρων που προτείνονται από το σύστημα και να καθορίσετε τα δικά σας μέτρα.

### Χωριστό σχέδιο δράσης

Όταν το σχέδιο δράσης αποτελεί χωριστό στάδιο, θα είναι προσβάσιμο μέσω πλοήγησης στην αριστερή πλευρά της οθόνης.

Κάντε «κλικ» στο «Δημιουργία σχεδίου δράσης» για να ξεκινήσετε την εκπόνηση του σχεδίου σας.

Στο στάδιο του σχεδίου δράσης το μενού στην αριστερή πλευρά της οθόνης εμφανίζει πλέον μόνον τους κινδύνους που φέρουν ένδειξη περαιτέρω δράσης, καθώς οι άλλοι κίνδυνοι έχουν επισημανθεί ως μη παρόντες.

Για κάθε κίνδυνο στον οποίο απαντήσατε «όχι» στο πλαίσιο της διαδικασίας αξιολόγησης και για τους κινδύνους κατά προτεραιότητα (ανεξαρτήτως θετικής ή αρνητικής απάντησης) θα κληθείτε να προσδιορίσετε μέτρα.

Κίνδυνος στο σχέδιο δράσης.

Μπορείτε είτε να επιλέξετε από έναν κατάλογο μέτρων που προτείνονται από το σύστημα είτε να καθορίσετε τα δικά σας μέτρα.

#### Προσθέστε το δικό σας μέτρο

Προσθήκη επιπλέον μέτρου.

Κάντε «κλικ» στο «Προσθήκη μέτρου» για να ξεκινήσετε τη διαδικασία προσδιορισμού κάποιου μέτρου πρόληψης. Θα πρέπει να προβείτε στις ακόλουθες ενέργειες:

- Να περιγράψετε τη γενική προσέγγιση που θα εφαρμοστεί για την εξάλειψη ή τη μείωση του κινδύνου.
- Προαιρετικώς, να δηλώσετε το επίπεδο εμπειρογνωμοσύνης ή/και τις δέουσες απαιτήσεις (π.χ. εδώ μπορείτε να προσθέσετε αν απαιτείται ειδική κατάρτιση ή εξωτερική εμπειρογνωμοσύνη για την αντιμετώπιση του συγκεκριμένου κινδύνου)
- Να εισάγετε πληροφορίες σχετικά με το πρόσωπο που είναι υπεύθυνο για την εφαρμογή του μέτρου.
- Να προσδιορίσετε τον προϋπολογισμό, εφόσον υπάρχει.
- Προαιρετικώς, να καθορίσετε τις ημερομηνίες έναρξης και πιθανής ολοκλήρωσης της εφαρμογής του μέτρου.

Μπορείτε να προσθέσετε όσα μέτρα χρειαστούν.

#### Προσθήκη τυποποιημένων μέτρων

Από τον τρόπο με τον οποίο ο εταίρος/υπεύθυνος ανάπτυξης διαμόρφωσε το εργαλείο OiRA εξαρτάται η διάθεση προκαθορισμένων τυποποιημένων μέτρων για την αντιμετώπιση συγκεκριμένων κινδύνων. Για την επιλογή ενός ή περισσότερων προκαθορισμένων μέτρων κάντε «κλικ» στο «Επιλογή τυποποιημένων μέτρων».

Σε ένα ιδιαίτερο παράθυρο ανοίγει ένα μενού που παρουσιάζει τα προτεινόμενα μέτρα. Κάντε «κλικ» στο «Προσθήκη» για κάθε μέτρο που επιθυμείτε να εφαρμόσετε.

Ακολούθως, τα προκαθορισμένα μέτρα απαριθμούνται στο σχέδιο δράσης σας. Η περιγραφή των εφαρμοστέων μέτρων είναι προδιατυπωμένη, όμως τα άλλα πεδία (ευθύνη, προϋπολογισμός, ημερομηνίες) μπορούν και πρέπει να συμπληρωθούν από εσάς.

Προσθήκη τυποποιημένων μέτρων.

Τόσο τα τυποποιημένα μέτρα όσο και τα μέτρα που προσδιορίσατε εσείς μπορούν να διαγραφούν ανά πάσα στιγμή.

## Έκθεση

Μετά την ολοκλήρωση του σχεδίου δράσης, μπορείτε να καταρτίσετε την έκθεση.

Εάν επιθυμείτε να συμπεριληφθεί κάποιο σχόλιο στην έκθεση, πληκτρολογήστε το κείμενό σας εδώ και αποθηκεύστε το.

Σχόλιο στην έκθεση.

Δείτε εδώ για να διαβάσετε περισσότερα σχετικά με τις διάφορες εκθέσεις και τον τρόπο χρήσης τους.

## Κατάσταση

Το μικρό κυκλικό διάγραμμα στο μενού στην αριστερή πλευρά της οθόνης δείχνει την πρόοδο που έχετε κάνει με το εργαλείο.

Η ενότητα που αφορά την κατάσταση παρέχει μια επισκόπηση των κινδύνων που έχετε αναγνωρίσει, όσων εξ αυτών έχετε αντιμετωπίσει λαμβάνοντας μέτρα, καθώς και των κινδύνων/δηλώσεων για τους οποίους/τις οποίες εκκρεμεί η απόκρισή σας.

Σελίδα που αφορά την κατάσταση.

Μόλις εεμφανισθεί η οθόνη που αφορά την κατάσταση, θα διαπιστώσετε πόση πρόοδο έχετε σημειώσει σε κάθε θεματική ενότητα. Η διαπίστωση αυτή μπορεί να σας βοηθήσει να επισημάνετε τις περιπτώσεις κινδύνων που ακόμη χρήζουν εκτίμησης ή να μεριμνήσετε για τη λήψη μέτρων για τους κινδύνους που έχετε αναγνωρίσει.

Scroll to top Load toolbar…
Back

## 3-carrying-out-a-risk-assessment.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More